@@ -14,7 +14,7 @@ Usage::
 # pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin
 from datetime import datetime
 import sys
-from typing import Any, Dict, IO, List, TYPE_CHECKING, Type, Union, overload
+from typing import Any, Dict, List, TYPE_CHECKING, Type, overload
 from botocore.exceptions import ClientError as Boto3ClientError
 from mypy_boto3_dms.paginator import (
     DescribeCertificatesPaginator,
@@ -462,7 +462,7 @@ class DatabaseMigrationServiceClient:
         self,
         CertificateIdentifier: str,
         CertificatePem: str = None,
-        CertificateWallet: Union[bytes, IO] = None,
+        CertificateWallet: bytes = None,
         Tags: List["TagTypeDef"] = None,
     ) -> ImportCertificateResponseTypeDef:
         """
