@@ -9,7 +9,7 @@ Usage::
 """
 from datetime import datetime
 import sys
-from typing import IO, List, Union
+from typing import List
 
 if sys.version_info >= (3, 8):
     from typing import Literal
@@ -117,7 +117,7 @@ CertificateTypeDef = TypedDict(
         "CertificateIdentifier": str,
         "CertificateCreationDate": datetime,
         "CertificatePem": str,
-        "CertificateWallet": Union[bytes, IO],
+        "CertificateWallet": bytes,
         "CertificateArn": str,
         "CertificateOwner": str,
         "ValidFromDate": datetime,
